import plotly.graph_objects as go


class Scatter(go.Scatter):
    def __init__(
        self,
        arg=None,
        alignmentgroup=None,
        cliponaxis=None,
        connectgaps=None,
        customdata=None,
        customdatasrc=None,
        dx=None,
        dy=None,
        error_x=None,
        error_y=None,
        fill=None,
        fillcolor=None,
        fillgradient=None,
        fillpattern=None,
        groupnorm=None,
        hoverinfo=None,
        hoverinfosrc=None,
        hoverlabel=None,
        hoveron=None,
        hovertemplate=None,
        hovertemplatesrc=None,
        hovertext=None,
        hovertextsrc=None,
        ids=None,
        idssrc=None,
        legend=None,
        legendgroup=None,
        legendgrouptitle=None,
        legendrank=None,
        legendwidth=None,
        line=None,
        marker=None,
        meta=None,
        metasrc=None,
        mode=None,
        name=None,
        offsetgroup=None,
        opacity=None,
        orientation=None,
        selected=None,
        selectedpoints=None,
        showlegend=None,
        stackgaps=None,
        stackgroup=None,
        stream=None,
        text=None,
        textfont=None,
        textposition=None,
        textpositionsrc=None,
        textsrc=None,
        texttemplate=None,
        texttemplatesrc=None,
        uid=None,
        uirevision=None,
        unselected=None,
        visible=None,
        x=None,
        x0=None,
        xaxis=None,
        xcalendar=None,
        xhoverformat=None,
        xperiod=None,
        xperiod0=None,
        xperiodalignment=None,
        xsrc=None,
        y=None,
        y0=None,
        yaxis=None,
        ycalendar=None,
        yhoverformat=None,
        yperiod=None,
        yperiod0=None,
        yperiodalignment=None,
        ysrc=None,
        zorder=None,
        **kwargs,
    ):
        line = line if line else dict(width=2)
        super().__init__(
            arg,
            alignmentgroup,
            cliponaxis,
            connectgaps,
            customdata,
            customdatasrc,
            dx,
            dy,
            error_x,
            error_y,
            fill,
            fillcolor,
            fillgradient,
            fillpattern,
            groupnorm,
            hoverinfo,
            hoverinfosrc,
            hoverlabel,
            hoveron,
            hovertemplate,
            hovertemplatesrc,
            hovertext,
            hovertextsrc,
            ids,
            idssrc,
            legend,
            legendgroup,
            legendgrouptitle,
            legendrank,
            legendwidth,
            line,
            marker,
            meta,
            metasrc,
            mode,
            name,
            offsetgroup,
            opacity,
            orientation,
            selected,
            selectedpoints,
            showlegend,
            stackgaps,
            stackgroup,
            stream,
            text,
            textfont,
            textposition,
            textpositionsrc,
            textsrc,
            texttemplate,
            texttemplatesrc,
            uid,
            uirevision,
            unselected,
            visible,
            x,
            x0,
            xaxis,
            xcalendar,
            xhoverformat,
            xperiod,
            xperiod0,
            xperiodalignment,
            xsrc,
            y,
            y0,
            yaxis,
            ycalendar,
            yhoverformat,
            yperiod,
            yperiod0,
            yperiodalignment,
            ysrc,
            zorder,
            **kwargs,
        )
